---
categories: web
title: Howto NextCloud
...


[NextCloud](https://docs.nextcloud.com/) est un logiciel libre qui permet de stocker des fichiers sur un serveur distant, communément appelé un « cloud ».

Ses fonctionnalités étendues et les nombreux plugins (nommés « Apps ») disponibles font de Nextcloud une plateforme collaborative très modulaire et une alternative libre remarquable face aux logiciels privateurs comme ~~Google Docs~~, ~~Google Drive~~ ou ~~Dropbox~~.

On y trouve, entre autres, des fonctionnalités essentielles comme le partage de fichiers, l'édition collaborative, la gestion de droits, un calendrier, la gestion des contacts...

Documentation Nextcloud officielle : <https://docs.nextcloud.com/>


# Côté client

## Utilisation

Les fichiers stockés sont accessibles :

* Via une interface web accessible à partir de n'importe quel navigateur (depuis un PC ou un smartphone) ;
* Dans un dossier local, grâce à l'application de synchronisation Nextcloud (disponible sur Linux, Mac et Windows) ;
* Sur un lecteur réseau avec le [protocole WebDAV](https://fr.wikipedia.org/wiki/WebDAV) (disponibles sur Linux, Mac et Windows) ;
* Via une application mobile [Android](https://nextcloud.fr.aptoide.com/app) ou [iPhone](https://apps.apple.com/fr/app/nextcloud/id1125420102).

Le choix des modes d'accès dépend de vos cas d'usage :

* Si vous utilisez Nextcloud pour stocker des données très volumineuses que vous ne voulez pas stocker localement, il est plus intéressant d'utiliser l'interface web et/ou un lecteur réseau WebDAV.
* Si vous utilisez Nextcloud comme solution de sauvegarde de vos fichiers locaux, vous aurez besoin de l'application de synchronisation.
* Si vous utilisez beaucoup les Apps Nexcloud, comme le calendrier ou l'éditeur collaboratif, vous utiliserez plutôt l'interface web.
* Etc.

Dans la plupart les cas d'usage, sauf stockage volumineux, nous conseillons d'installer l'application de synchronisation et d'utiliser l'interface web pour tout usage autre que du stockage ou du partage (collaboration, calendrier...).


### Synchronisation automatique

L'application de synchronisation copie et maintient à jour vos fichiers Nextcloud sur votre ordinateur dans un dossier local de votre choix, accessible comme d'habitude avec votre gestionnaire de fichiers.

Les fichiers synchronisés seront accessibles sans latence. Cependant, contrairement au lecteur réseau WebDAV, ils prendront de l'espace sur votre disque dur.

L'application s'exécute en tâche de fond et ajoute une icône dans la barre des tâches, à partir de laquelle on peut configurer la synchronisation.


#### Installation de l'application de synchronisation sur Debian

Note : Le nom des paquets peut varier selon votre distribution.

Sur **Debian**, le paquet à installer est [nextcloud-desktop](https://packages.debian.org/stable/nextcloud-desktop).

S'il n'est pas visible dans les icônes de la barre des tâches après l'installation, il faut le lancer manuellement via le menu des programmes et vérifier dans ses paramètres que l'option « Lancer au démarrage du système » est bien cochée.

Par exemple, pour le lancer sur XFCE : `Menu > Accessoires > Client de synchronisation Nextcloud`.

S'il ne démarre pas automatiquement au prochain redémarrage, vous devez l'ajouter manuellement aux applications démarrées automatiquement par votre environnement de bureau (KDE, Gnome, XFCE, Windows...).

Par exemple, pour XFCE :

* `Menu > Paramètres > Session et démarrage > Démarrage automatique d'application > +`
* Commande à exécuter : `/usr/bin/nextcloud --background`


#### Installation de l'application de synchronisation sur d'autres systèmes

Si votre système d'exploitation ne fournit pas de paquet pour installer l'application de synchronisation (**Windows, MacOS, distributions Linux n'ayant pas de paquet Nextcloud**), vous pouvez utiliser :

* Les binaires pré-compilés sur le [GitHub de Nextcloud](https://github.com/nextcloud/desktop).
* Le fichier d'installation ou le binaire sur le [site de Nextcloud](https://nextcloud.com/install/#install-clients).

Cependant, avec ce type d'installation, vous devez effectuer les mises-à-jour de l'application manuellement.


### Lecteur réseau (via le protocole WebDAV)

Cette solution permet de rendre les fichiers accessibles dans votre gestionnaire de fichiers via un lecteur réseau, avec un temps de latence qui dépendra de votre connexion à internet et de la taille des fichiers. Contrairement au client de bureau, ils ne prendront pas de place sur votre disque dur.

L'avantage du protocole WebDAV est d'être indépendant du système d'exploitation que vous utilisez.
En revanche, en cas de coupure d'accès à internet, vous ne pourrez pas accéder à vos fichiers.

L'url à renseignée est `https://nextcloud.evolix.org/remote.php/dav/files/$login`.


#### Ajout du lecteur réseau WebDAV à votre gestionnaire de fichiers Linux

La plupart des gestionnaires de fichiers prennent en charge le protocole WebDAV nativement.
Cette solution a l'avantage de ne pas nécessiter l'installation de paquets supplémentaires.

En général, il suffit d'entrer l'URL suivante dans la barre de chemin de votre gestionnaire de fichiers, en adaptant `$login` :

* Thunar, Nautilus, Caja, Nemo : `davs://nextcloud.evolix.org/remote.php/dav/files/$login`
* Dolphin : `webdavs://nextcloud.evolix.org/remote.php/dav/files/$login`

Selon votre configuration ou la version de votre gestionnaire de fichiers, il faut parfois cliquer sur la barre de chemins pour pouvoir entrer l'URL (Dolphin), cliquer sur une icône à côté (Nemo, Caja), ou ajouter explicitement un nouveau lecteur réseau (Nautilus).

Sur Nautilus, il n'y a pas de barre de chemin, il faut ajouter un lecteur réseau en cliquant sur `+ Autres emplacements` dans le panneau latéral de gauche, puis renseigner l'URL WebDAV de l'instance Nextcloud dans « Connexion à un serveur ».


#### Intégration dans votre environnement de bureau Linux

Certains environnements de bureau proposent une intégration native de Nextcloud :

* Gnome (Nautilus) : [nautilus-nextcloud](https://packages.debian.org/stable/nautilus-nextcloud), (documentation)[https://docs.nextcloud.com/server/19/user_manual/pim/sync_gnome.html]
* KDE (Dolphin) : [dolphin-nextcloud](https://packages.debian.org/stable/dolphin-nextcloud)
* Cinnamon, Unity (Nemo) : [nemo-nextcloud](https://packages.debian.org/stable/nemo-nextcloud)
* Mate (Caja) : [caja-nextcloud](https://packages.debian.org/stable/caja-nextcloud)

Généralement, vous pouvez ensuite configurer votre compte Nextcloud dans les paramètres de votre bureau.

Par exemple, pour Gnome, cela se passe dans `Settings > Online accounts > Nextcloud`.

Ces intégrations ajoutent un lecteur réseau nextcloudavec le protocole WebDAV et permettent de synchroniser votre calendrier et vos contacts avec les applications du bureau.


#### Ajout du lecteur réseau WebDAV sur Windows

Dans l'explorateur de fichiers : `Clic droit sur PC > Connecter un lecteur réseau`.

Dans `Dossier`, indiquez `A COMPLETER`.


## Administration

### Gestion des droits

Pour gérer proprement les droits sur les partages, il est préférable de gérer les droits d'accès par groupe que par utilisateur.trice.s.

Le plugin « Group folders » permet de créer des groupes de partage et de configurer les droits d'accès par groupe dans l'interface (bouton « Utilisateurs » dans le menu déroulant de l'administrateur.trice en haut à droite de l'interface web).

Sans ce plugin, un.e utilisateur.trice peut créer un répertoire et le partager avec certains droits. Cependant, ce n'est pas pratique : iel peut retirer les droits, ou on peut être embêté.e si l'on doit supprimer l'utilisateur.trice dans le futur.

Page du plugin : <https://apps.nextcloud.com/apps/groupfolders>


### Mise-à-jour

Dans Nextcloud, les mises-à-jour se font de version en version. S'il y a plusieurs versions de retard, il faut le mettre à jour autant de fois qu'il y a de versions de retard.

Les mises-à-jour peuvent être faites par l'adminsitrateur.trice via l'interface web.

Pour cela : cliquez sur le bouton rond en haut à droite > Paramètres > Vue d'ensemble > Ouvrir le système de mise-à-jour.
Puis suivez les instructions.

Attention, il ne faut pas fermer la page pendant la mise-à-jour, sinon vous resterez bloqué.e en mode maintenance.

A la fin des opérations de mise-à-jour, l'interface propose de quitter le mode maintenance.

En cas d'oubli, votre interface web sera [bloquée en mode maintenance](HowtoNextCloud#interface-web-bloquee-en-mode-maintenance).


## Dépannage

### Interface web bloquée en mode maintenance

C'est une erreur très courante et anodine. Elle se produit lorsque, à la fin d'une mise-à-jour effectuée via l'interface web, on sélectionne (par oubli ou par erreur) « rester en mode maintenance ».

Pour sortir du mode maintenance par la suite, il faut faire appel à votre administrateur.trice système qui a un accès au serveur en ligne de commande, et qui va suivre [la procédure ci-dessous](HowtoNextCloud#interface-web-bloquée-en-mode-maintenance-1)


# Côté serveur

Chez Evolix, notre offre [NextCloud SAAS](https://evolix.com/offres-saas.html) fonctionne sur le serveur web Nginx, le serveur de base de données MariaDB et le serveur de cache Redis.


## Installation

Evolix met à votre disposition dans son dépôt public [ansible-roles](https://gitea.evolix.org/evolix/ansible-roles>) un rôle Ansible pour installer automatiquement Nextcloud !

Si vous êtes intéressé.e par d'autres méthodes d'installation :

* Documentation d'installation officielle : <https://docs.nextcloud.com/server/latest/admin_manual/installation>.
* La dernière version peut être téléchargée sur <https://download.nextcloud.com/server/releases/>.


## Administration via l'utilitaire `occ` en ligne de commande

NextCloud propose un utilitaire en ligne de commande très bien conçu et nommé `occ`.

Pour l'utiliser, il faut se logger en tant que l'utilisateur de l'instance Nextcloud à administrer, puis se déplacer dans le répertoire de l'instance.

L'utilitaire est écrit en PHP, il exécute donc de la manière suivante, par exemple pour obtenir la liste des commandes :

```
php occ
```


### Interface web bloquée en mode maintenance

C'est une erreur très courante et anodine, lorsque l'on oublie ou que l'on se trompe lors de la dernière étape de la mise-à-jour via l'interface web.

Pour être sûr.e que la mise-à-jour s'est bien déroulée, on peut la relancer :

```
php occ upgrade
```

Puis, on sort du mode maintenance :

```
php occ maintenance:mode --off
```

